@@ -4,26 +4,23 @@ from pathlib import Path
 from typing import Iterable
 
 from ldb.add import add, process_args_for_add
-from ldb.cli_utils import add_data_object_arguments
+from ldb.cli_utils import add_data_obj_params
 from ldb.core import get_ldb_instance
 from ldb.dataset import apply_queries
 from ldb.exceptions import LDBException
-from ldb.func_utils import apply_optional
-from ldb.query.search import get_bool_search_func
 from ldb.utils import DATASET_PREFIX, ROOT
 
 
 def add_command(options: Namespace) -> None:
-    ldb_dir = get_ldb_instance()
-    search = apply_optional(get_bool_search_func, options.annotation_query)
-    file_search = apply_optional(get_bool_search_func, options.file_query)
     paths = options.paths
+    query_args = options.query_args
     if not paths:
-        if search is None and file_search is None:
+        if not query_args:
             raise LDBException(
                 "Must provide either a query or at least one path",
             )
         paths = [f"{DATASET_PREFIX}{ROOT}"]
+    ldb_dir = get_ldb_instance()
     data_object_hashes, annotation_hashes, message = process_args_for_add(
         ldb_dir,
         paths,
@@ -34,10 +31,9 @@ def add_command(options: Namespace) -> None:
 
     collection = apply_queries(
         ldb_dir,
-        search,
-        file_search,
         data_object_hashes,
         annotation_hashes,
+        query_args,
     )
     print("Adding to working dataset...")
     add(
@@ -55,5 +51,5 @@ def add_parser(
         parents=parents,
         help="Add a data objects under a certain path",
     )
-    add_data_object_arguments(parser)
+    add_data_obj_params(parser, dest="query_args")
     parser.set_defaults(func=add_command)
